#include <stdio.h>
#include <fcntl.h>
#include <gdbm.h>

main(int argc, char *argv[])
{
    GDBM_FILE dbp;
    datum kdat, vdat;
    

    dbp = gdbm_open(argv[1], 64, O_RDWR+O_CREAT, 0777, NULL);
    if (dbp == NULL)
    {
	perror("dbadd: dbm_open");
	exit(1);
    }

    kdat.dsize = strlen(argv[2]);
    kdat.dptr = argv[2];

    vdat.dsize = strlen(argv[3]);
    vdat.dptr = argv[3];
    
    if (gdbm_store(dbp, kdat, vdat, GDBM_REPLACE) < 0)
    {
	perror("dbadd: dbm_store");
	gdbm_close(dbp);
	exit(1);
    }
    
    gdbm_close(dbp);
    exit(0);
}
